"use strict";

import { useCallback, useRef, useState } from 'react';
import { BackHandler, Keyboard, LayoutAnimation, Platform, TextInput } from 'react-native';
export const usePlatformController = () => {
  const [keyboardHeight, setKeyboardHeight] = useState(0);
  const onKeyboardDidShow = useCallback(e => {
    LayoutAnimation.easeInEaseOut();
    setKeyboardHeight(e.endCoordinates.height);
  }, []);
  const onKeyboardDidHide = useCallback(() => {
    LayoutAnimation.easeInEaseOut();
    setKeyboardHeight(0);
  }, []);
  const focusedTextInput = useRef(null);
  const androidBackButtonPressSub = useRef(null);
  const keyboardDidShowSub = useRef(null);
  const keyboardDidHideSub = useRef(null);
  const onShow = useCallback(() => {
    focusedTextInput.current = TextInput.State.currentlyFocusedInput();
    TextInput.State.blurTextInput(focusedTextInput.current);
    if (Platform.OS === 'android') {
      androidBackButtonPressSub.current = BackHandler.addEventListener('hardwareBackPress', () => {
        return true;
      });
    }
    if (Platform.OS === 'ios') {
      keyboardDidShowSub.current = Keyboard.addListener('keyboardDidShow', onKeyboardDidShow);
      keyboardDidHideSub.current = Keyboard.addListener('keyboardDidHide', onKeyboardDidHide);
    }
  }, [onKeyboardDidHide, onKeyboardDidShow]);
  const onHide = useCallback(() => {
    if (focusedTextInput.current) {
      TextInput.State.focusTextInput(focusedTextInput.current);
    }
    if (Platform.OS === 'android') {
      androidBackButtonPressSub.current?.remove();
    }
    if (Platform.OS === 'ios') {
      keyboardDidShowSub.current?.remove();
      keyboardDidHideSub.current?.remove();
    }
    setKeyboardHeight(0);
  }, []);
  return {
    bottomOffset: keyboardHeight,
    onHide,
    onShow
  };
};
//# sourceMappingURL=controller.platform.native.js.map