"use strict";

import { useEffect, useMemo, useCallback } from 'react';
import { alert } from "./alert.api.js";
import { useController } from "./controller.js";
import { Backdrop } from "../../components/Backdrop/index.js";
import { Alert } from "../../components/Alert/index.js";
import { StyleSheet, View } from 'react-native';
import { styles } from "./styles.js";
import { ConfettiContainer } from "../ConfettiContainer/index.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export const AlertContainer = ({
  animationDuration = 200,
  config
}) => {
  const {
    bottomOffset,
    clearQueue,
    confirm,
    currentAlert,
    getAlertData,
    hide,
    isHiding,
    isShown,
    show,
    showError,
    success,
    update
  } = useController({
    animationDuration,
    config
  });
  useEffect(() => {
    // @ts-ignore: Type 'unknown' is not assignable to type 'R'
    alert.show = show;
    alert.hide = hide;
    // @ts-ignore: Type 'unknown' is not assignable to type 'R'
    alert.success = success;
    alert.update = update;
    alert.clearQueue = clearQueue;
    // @ts-ignore: Type 'unknown' is not assignable to type 'R'
    alert.getAlertData = getAlertData;
    // @ts-ignore: Type 'unknown' is not assignable to type 'R'
    alert.confirm = confirm;
    // @ts-ignore: Type 'unknown' is not assignable to type 'R'
    alert.error = showError;
    alert.isShown = isShown;
  }, [clearQueue, hide, show, success, update, getAlertData, isShown, confirm, showError]);
  const containerStyle = useMemo(() => StyleSheet.compose(styles.container, {
    bottom: bottomOffset
  }), [bottomOffset]);
  const renderConfetti = useCallback(() => {
    const shouldRender = currentAlert?.confetti;
    if (shouldRender) {
      const currentAlertConfettiProps = typeof currentAlert.confetti === 'boolean' ? undefined : currentAlert.confetti;
      const globalProps = config?.confetti;
      const confettiProps = {
        ...globalProps,
        ...currentAlertConfettiProps
      };
      return /*#__PURE__*/_jsx(ConfettiContainer, {
        ...confettiProps
      });
    }
    return null;
  }, [currentAlert?.confetti, config?.confetti]);
  return currentAlert ? /*#__PURE__*/_jsxs(View, {
    style: containerStyle,
    children: [/*#__PURE__*/_jsx(Backdrop, {
      animationDuration: animationDuration,
      isHiding: isHiding,
      backgroundColor: config?.backdropBackgroundColor
    }), renderConfetti(), /*#__PURE__*/_jsx(Alert, {
      ...currentAlert,
      animationDuration: animationDuration,
      isHiding: isHiding
    })]
  }) : null;
};
//# sourceMappingURL=index.js.map